==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/domain/impl/S_ENUMSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.domain.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.domain.EnumerationDataTypeSet;
import io.ciera.tool.sql.ooaofooa.domain.S_ENUM;
import io.ciera.tool.sql.ooaofooa.domain.S_ENUMSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.EnumerationDataTypeSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.S_ENUMSetImpl;
import io.ciera.tool.sql.ooaofooa.value.LiteralEnumeratorSet;
import io.ciera.tool.sql.ooaofooa.value.impl.LiteralEnumeratorSetImpl;

import java.util.Arrays;
import java.util.List;


public class S_ENUMSetImpl extends InstanceSet<S_ENUMSet,S_ENUM> implements S_ENUMSet {

    // attributes
    @Override
    public void setPrevious_Enum_ID( UniqueId ref_Previous_Enum_ID ) throws XtumlException {
        for ( S_ENUM s_enum : this ) s_enum.setPrevious_Enum_ID( ref_Previous_Enum_ID );
    }
    @Override
    public void setEDT_DT_ID( UniqueId ref_EDT_DT_ID ) throws XtumlException {
        for ( S_ENUM s_enum : this ) s_enum.setEDT_DT_ID( ref_EDT_DT_ID );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( S_ENUM s_enum : this ) s_enum.setDescrip( m_Descrip );
    }
    @Override
    public void setEnum_ID( UniqueId m_Enum_ID ) throws XtumlException {
        for ( S_ENUM s_enum : this ) s_enum.setEnum_ID( m_Enum_ID );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( S_ENUM s_enum : this ) s_enum.setName( m_Name );
    }


    // selections
    @Override
    public EnumerationDataTypeSet R27_is_defined_by_EnumerationDataType() throws XtumlException {
        EnumerationDataTypeSet enumerationdatatypeset = new EnumerationDataTypeSetImpl();
        for ( S_ENUM s_enum : this ) enumerationdatatypeset.add( s_enum.R27_is_defined_by_EnumerationDataType() );
        return enumerationdatatypeset;
    }
    @Override
    public S_ENUMSet R56_precedes_S_ENUM() throws XtumlException {
        S_ENUMSet s_enumset = new S_ENUMSetImpl();
        for ( S_ENUM s_enum : this ) s_enumset.add( s_enum.R56_precedes_S_ENUM() );
        return s_enumset;
    }
    @Override
    public S_ENUMSet R56_succeeds_S_ENUM() throws XtumlException {
        S_ENUMSet s_enumset = new S_ENUMSetImpl();
        for ( S_ENUM s_enum : this ) s_enumset.add( s_enum.R56_succeeds_S_ENUM() );
        return s_enumset;
    }
    @Override
    public LiteralEnumeratorSet R824_is_value_of_LiteralEnumerator() throws XtumlException {
        LiteralEnumeratorSet literalenumeratorset = new LiteralEnumeratorSetImpl();
        for ( S_ENUM s_enum : this ) literalenumeratorset.addAll( s_enum.R824_is_value_of_LiteralEnumerator() );
        return literalenumeratorset;
    }


    @Override
    public S_ENUM nullElement() {
        return S_ENUMImpl.EMPTY_S_ENUM;
    }

    @Override
    public S_ENUMSet emptySet() {
      return new S_ENUMSetImpl();
    }

    @Override
    public S_ENUMSet value() {
        return this;
    }

    @Override
    public List<S_ENUM> elements() {
        S_ENUM[] elements = toArray(new S_ENUM[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/domain/impl/S_ENUMSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.domain.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.domain.EnumerationDataTypeSet;
import io.ciera.tool.sql.ooaofooa.domain.S_ENUM;
import io.ciera.tool.sql.ooaofooa.domain.S_ENUMSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.EnumerationDataTypeSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.S_ENUMSetImpl;
import io.ciera.tool.sql.ooaofooa.value.LiteralEnumeratorSet;
import io.ciera.tool.sql.ooaofooa.value.impl.LiteralEnumeratorSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class S_ENUMSetImpl extends InstanceSet<S_ENUMSet,S_ENUM> implements S_ENUMSet {

    public S_ENUMSetImpl() {
    }

    public S_ENUMSetImpl(Comparator<? super S_ENUM> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( S_ENUM s_enum : this ) s_enum.setName( m_Name );
    }
    @Override
    public void setEnum_ID( UniqueId m_Enum_ID ) throws XtumlException {
        for ( S_ENUM s_enum : this ) s_enum.setEnum_ID( m_Enum_ID );
    }
    @Override
    public void setPrevious_Enum_ID( UniqueId ref_Previous_Enum_ID ) throws XtumlException {
        for ( S_ENUM s_enum : this ) s_enum.setPrevious_Enum_ID( ref_Previous_Enum_ID );
    }
    @Override
    public void setEDT_DT_ID( UniqueId ref_EDT_DT_ID ) throws XtumlException {
        for ( S_ENUM s_enum : this ) s_enum.setEDT_DT_ID( ref_EDT_DT_ID );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( S_ENUM s_enum : this ) s_enum.setDescrip( m_Descrip );
    }


    // selections
    @Override
    public EnumerationDataTypeSet R27_is_defined_by_EnumerationDataType() throws XtumlException {
        EnumerationDataTypeSet enumerationdatatypeset = new EnumerationDataTypeSetImpl();
        for ( S_ENUM s_enum : this ) enumerationdatatypeset.add( s_enum.R27_is_defined_by_EnumerationDataType() );
        return enumerationdatatypeset;
    }
    @Override
    public S_ENUMSet R56_precedes_S_ENUM() throws XtumlException {
        S_ENUMSet s_enumset = new S_ENUMSetImpl();
        for ( S_ENUM s_enum : this ) s_enumset.add( s_enum.R56_precedes_S_ENUM() );
        return s_enumset;
    }
    @Override
    public S_ENUMSet R56_succeeds_S_ENUM() throws XtumlException {
        S_ENUMSet s_enumset = new S_ENUMSetImpl();
        for ( S_ENUM s_enum : this ) s_enumset.add( s_enum.R56_succeeds_S_ENUM() );
        return s_enumset;
    }
    @Override
    public LiteralEnumeratorSet R824_is_value_of_LiteralEnumerator() throws XtumlException {
        LiteralEnumeratorSet literalenumeratorset = new LiteralEnumeratorSetImpl();
        for ( S_ENUM s_enum : this ) literalenumeratorset.addAll( s_enum.R824_is_value_of_LiteralEnumerator() );
        return literalenumeratorset;
    }


    @Override
    public S_ENUM nullElement() {
        return S_ENUMImpl.EMPTY_S_ENUM;
    }

    @Override
    public S_ENUMSet emptySet() {
      return new S_ENUMSetImpl();
    }

    @Override
    public S_ENUMSet emptySet(Comparator<? super S_ENUM> comp) {
      return new S_ENUMSetImpl(comp);
    }

    @Override
    public S_ENUMSet value() {
        return this;
    }

    @Override
    public List<S_ENUM> elements() {
        S_ENUM[] elements = toArray(new S_ENUM[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}
